# Form implementation generated from reading ui file 'primitive_compound_frame_base.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PySide6 import QtCore, QtGui, QtWidgets


class Ui_PrimitiveCompoundFrame(object):
  def setupUi(self, PrimitiveCompoundFrame):
    PrimitiveCompoundFrame.setObjectName("PrimitiveCompoundFrame")
    PrimitiveCompoundFrame.resize(1345, 101)
    PrimitiveCompoundFrame.setFrameShape(QtWidgets.QFrame.Shape.NoFrame)
    self.verticalLayout = QtWidgets.QVBoxLayout(PrimitiveCompoundFrame)
    self.verticalLayout.setObjectName("verticalLayout")
    self.mainVerticalLayout = QtWidgets.QVBoxLayout()
    self.mainVerticalLayout.setObjectName("mainVerticalLayout")
    self.addPushButton = QtWidgets.QPushButton(parent=PrimitiveCompoundFrame)
    sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
    sizePolicy.setHorizontalStretch(0)
    sizePolicy.setVerticalStretch(0)
    sizePolicy.setHeightForWidth(self.addPushButton.sizePolicy().hasHeightForWidth())
    self.addPushButton.setSizePolicy(sizePolicy)
    self.addPushButton.setMinimumSize(QtCore.QSize(100, 0))
    self.addPushButton.setObjectName("addPushButton")
    self.mainVerticalLayout.addWidget(self.addPushButton)
    self.compoundHorizontalLayout = QtWidgets.QHBoxLayout()
    self.compoundHorizontalLayout.setObjectName("compoundHorizontalLayout")
    self.mainVerticalLayout.addLayout(self.compoundHorizontalLayout)
    self.verticalLayout.addLayout(self.mainVerticalLayout)

    self.retranslateUi(PrimitiveCompoundFrame)
    QtCore.QMetaObject.connectSlotsByName(PrimitiveCompoundFrame)

  def retranslateUi(self, PrimitiveCompoundFrame):
    _translate = QtCore.QCoreApplication.translate
    PrimitiveCompoundFrame.setWindowTitle(_translate("PrimitiveCompoundFrame", "Frame"))
    PrimitiveCompoundFrame.setToolTip(_translate("PrimitiveCompoundFrame", "Set the compound type for metadata block."))
    self.addPushButton.setToolTip(_translate("PrimitiveCompoundFrame", "Add a new compound entry to the list."))
    self.addPushButton.setText(_translate("PrimitiveCompoundFrame", "Add"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    PrimitiveCompoundFrame = QtWidgets.QFrame()
    ui = Ui_PrimitiveCompoundFrame()
    ui.setupUi(PrimitiveCompoundFrame)
    PrimitiveCompoundFrame.show()
    sys.exit(app.exec())
