# Form implementation generated from reading ui file 'controlled_vocab_frame_base.ui'
#
# Created by: PyQt6 UI code generator 6.4.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PySide6 import QtCore, QtGui, QtWidgets


class Ui_ControlledVocabularyFrame(object):
  def setupUi(self, ControlledVocabularyFrame):
    ControlledVocabularyFrame.setObjectName("ControlledVocabularyFrame")
    ControlledVocabularyFrame.resize(1034, 91)
    self.verticalLayout_2 = QtWidgets.QVBoxLayout(ControlledVocabularyFrame)
    self.verticalLayout_2.setObjectName("verticalLayout_2")
    self.mainVerticalLayout = QtWidgets.QVBoxLayout()
    self.mainVerticalLayout.setObjectName("mainVerticalLayout")
    self.addPushButton = QtWidgets.QPushButton(parent=ControlledVocabularyFrame)
    sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
    sizePolicy.setHorizontalStretch(0)
    sizePolicy.setVerticalStretch(0)
    sizePolicy.setHeightForWidth(self.addPushButton.sizePolicy().hasHeightForWidth())
    self.addPushButton.setSizePolicy(sizePolicy)
    self.addPushButton.setMinimumSize(QtCore.QSize(100, 0))
    self.addPushButton.setObjectName("addPushButton")
    self.mainVerticalLayout.addWidget(self.addPushButton)
    self.vocabHorizontalLayout = QtWidgets.QHBoxLayout()
    self.vocabHorizontalLayout.setObjectName("vocabHorizontalLayout")
    self.vocabComboBox = QtWidgets.QComboBox(parent=ControlledVocabularyFrame)
    self.vocabComboBox.setObjectName("vocabComboBox")
    self.vocabHorizontalLayout.addWidget(self.vocabComboBox)
    self.deletePushButton = QtWidgets.QPushButton(parent=ControlledVocabularyFrame)
    self.deletePushButton.setEnabled(False)
    sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
    sizePolicy.setHorizontalStretch(0)
    sizePolicy.setVerticalStretch(0)
    sizePolicy.setHeightForWidth(self.deletePushButton.sizePolicy().hasHeightForWidth())
    self.deletePushButton.setSizePolicy(sizePolicy)
    self.deletePushButton.setMinimumSize(QtCore.QSize(100, 0))
    self.deletePushButton.setObjectName("deletePushButton")
    self.vocabHorizontalLayout.addWidget(self.deletePushButton)
    self.mainVerticalLayout.addLayout(self.vocabHorizontalLayout)
    self.verticalLayout_2.addLayout(self.mainVerticalLayout)

    self.retranslateUi(ControlledVocabularyFrame)
    QtCore.QMetaObject.connectSlotsByName(ControlledVocabularyFrame)

  def retranslateUi(self, ControlledVocabularyFrame):
    _translate = QtCore.QCoreApplication.translate
    ControlledVocabularyFrame.setWindowTitle(_translate("ControlledVocabularyFrame", "Frame"))
    self.addPushButton.setToolTip(_translate("ControlledVocabularyFrame", "Add a new controlled vocabulary list entry."))
    self.addPushButton.setText(_translate("ControlledVocabularyFrame", "Add"))
    self.vocabComboBox.setToolTip(_translate("ControlledVocabularyFrame", "Select the controlled vocabulary."))
    self.deletePushButton.setToolTip(_translate("ControlledVocabularyFrame", "Delete this particular vocabulary entry."))
    self.deletePushButton.setText(_translate("ControlledVocabularyFrame", "Delete"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    ControlledVocabularyFrame = QtWidgets.QFrame()
    ui = Ui_ControlledVocabularyFrame()
    ui.setupUi(ControlledVocabularyFrame)
    ControlledVocabularyFrame.show()
    sys.exit(app.exec())
